Class: Google::Apis::AgentidentityV1::AccessSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb

Overview

Message describing AccessSummary object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AccessSummary

Returns a new instance of AccessSummary.



90
91
92
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 90

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_providerString

Output only. The auth_provider that this access summary is associated with. Corresponds to the JSON property authProvider

Returns:

  • (String)


32
33
34
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 32

def auth_provider
  @auth_provider
end

#auth_provider_typeString

Output only. The type of the connector that was used to create this access summary. Corresponds to the JSON property authProviderType

Returns:

  • (String)


38
39
40
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 38

def auth_provider_type
  @auth_provider_type
end

#first_access_timeString

Output only. The first time this user has interacted with this workload. Rounded to the previous hour. Corresponds to the JSON property firstAccessTime

Returns:

  • (String)


44
45
46
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 44

def first_access_time
  @first_access_time
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


49
50
51
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 49

def labels
  @labels
end

#last_access_timeString

Output only. The most recent time this user has interacted with this workload. Rounded to the previous hour. Corresponds to the JSON property lastAccessTime

Returns:

  • (String)


55
56
57
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 55

def last_access_time
  @last_access_time
end

#nameString

Output only. Identifier. Name of the AccessSummary Corresponds to the JSON property name

Returns:

  • (String)


60
61
62
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 60

def name
  @name
end

#purge_timeString

Output only. The time when this access summary is permanently deleted. Corresponds to the JSON property purgeTime

Returns:

  • (String)


65
66
67
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 65

def purge_time
  @purge_time
end

#scopesArray<String>

Output only. All scopes that have been used by this user with this workload. The number of scopes is limited to 200. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


71
72
73
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 71

def scopes
  @scopes
end

#token_urlString

Output only. The url of the authentication server that was accessed. Corresponds to the JSON property tokenUrl

Returns:

  • (String)


76
77
78
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 76

def token_url
  @token_url
end

#user_idString

Output only. The user_id provided by the workload application for this user. Not verified by Google. Corresponds to the JSON property userId

Returns:

  • (String)


82
83
84
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 82

def user_id
  @user_id
end

#workload_idString

Output only. The identity bound to the workload that this user interacted with to produce this AccessSummary. Will typically be an agentic spiffe id Corresponds to the JSON property workloadId

Returns:

  • (String)


88
89
90
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 88

def workload_id
  @workload_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 95

def update!(**args)
  @auth_provider = args[:auth_provider] if args.key?(:auth_provider)
  @auth_provider_type = args[:auth_provider_type] if args.key?(:auth_provider_type)
  @first_access_time = args[:first_access_time] if args.key?(:first_access_time)
  @labels = args[:labels] if args.key?(:labels)
  @last_access_time = args[:last_access_time] if args.key?(:last_access_time)
  @name = args[:name] if args.key?(:name)
  @purge_time = args[:purge_time] if args.key?(:purge_time)
  @scopes = args[:scopes] if args.key?(:scopes)
  @token_url = args[:token_url] if args.key?(:token_url)
  @user_id = args[:user_id] if args.key?(:user_id)
  @workload_id = args[:workload_id] if args.key?(:workload_id)
end