Class: Google::Apis::AgentidentityV1::AuthProvider

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb

Overview

Message describing AuthProvider object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthProvider

Returns a new instance of AuthProvider.



276
277
278
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_scopesArray<String>

Optional. List of scopes that are allowed to be requested for this auth_provider. If this list is non-empty, only scopes within this list may be requested. If this list is empty, all scopes may be requested. Scopes appearing in blocked_scopes are disallowed even if they appear in allowed_scopes. The number of allowed scopes is limited to 200. Corresponds to the JSON property allowedScopes

Returns:

  • (Array<String>)


211
212
213
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 211

def allowed_scopes
  @allowed_scopes
end

#auth_provider_type_paramsGoogle::Apis::AgentidentityV1::AuthProviderTypeParams

AuthProvider type specific parameters. Required when creating an auth_provider. Corresponds to the JSON property authProviderTypeParams



216
217
218
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 216

def auth_provider_type_params
  @auth_provider_type_params
end

#blocked_scopesArray<String>

Optional. List of scopes that are blocked from being requested for this auth_provider. If a scope appears in this list, it will not be requested, even if it also appears in allowed_scopes. blocked_scopes takes precedence over allowed_scopes. The number of blocked scopes is limited to 200. Corresponds to the JSON property blockedScopes

Returns:

  • (Array<String>)


224
225
226
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 224

def blocked_scopes
  @blocked_scopes
end

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


229
230
231
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 229

def create_time
  @create_time
end

#deletedBoolean Also known as: deleted?

Output only. This is set to true if the auth_provider is deleted. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


234
235
236
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 234

def deleted
  @deleted
end

#descriptionString

Optional. Description of the resource. Must be less than 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


240
241
242
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 240

def description
  @description
end

#expire_timeString

Output only. The time when the auth_provider will expire. Corresponds to the JSON property expireTime

Returns:

  • (String)


245
246
247
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 245

def expire_time
  @expire_time
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


250
251
252
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 250

def labels
  @labels
end

#nameString

Identifier. The full resource name of the auth_provider. Format: projects/ project/locations/location/authProviders/auth_provider Corresponds to the JSON property name

Returns:

  • (String)


256
257
258
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 256

def name
  @name
end

#stateString

Output only. The state of the auth_provider. Corresponds to the JSON property state

Returns:

  • (String)


261
262
263
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 261

def state
  @state
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


266
267
268
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 266

def update_time
  @update_time
end

#workload_idsArray<String>

Optional. Input only. Represents the workload identity in IAM principal:// format of the agent(s) that will use this AuthProvider. Example: principal:// agents.global.org-$ORG_ID.system.id.goog/resources/aiplatform/projects/ PROJECT_ID/locations/LOCATIONS/reasoningEngines/ID` Corresponds to the JSON propertyworkloadIds`

Returns:

  • (Array<String>)


274
275
276
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 274

def workload_ids
  @workload_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 281

def update!(**args)
  @allowed_scopes = args[:allowed_scopes] if args.key?(:allowed_scopes)
  @auth_provider_type_params = args[:auth_provider_type_params] if args.key?(:auth_provider_type_params)
  @blocked_scopes = args[:blocked_scopes] if args.key?(:blocked_scopes)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deleted = args[:deleted] if args.key?(:deleted)
  @description = args[:description] if args.key?(:description)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workload_ids = args[:workload_ids] if args.key?(:workload_ids)
end