Class: Google::Apis::AgentidentityV1::Authorization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb

Overview

Message describing Authorization object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Authorization

Returns a new instance of Authorization.



370
371
372
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_user_idString

Output only. The client_user_id provided by the client application for their end user. Not verified by Google. Corresponds to the JSON property clientUserId

Returns:

  • (String)


342
343
344
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 342

def client_user_id
  @client_user_id
end

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 347

def create_time
  @create_time
end

#nameString

Identifier. name of resource Corresponds to the JSON property name

Returns:

  • (String)


352
353
354
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 352

def name
  @name
end

#scopesArray<String>

Output only. The scopes actually granted by the end user during the consent flow. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


358
359
360
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 358

def scopes
  @scopes
end

#stateString

Output only. The state of the authorization. Corresponds to the JSON property state

Returns:

  • (String)


363
364
365
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 363

def state
  @state
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 368

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



375
376
377
378
379
380
381
382
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 375

def update!(**args)
  @client_user_id = args[:client_user_id] if args.key?(:client_user_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @scopes = args[:scopes] if args.key?(:scopes)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end