Class: Google::Apis::AgentidentityV1::DisableAuthProviderRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb

Overview

Message for disabling an AuthProvider

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DisableAuthProviderRequest

Returns a new instance of DisableAuthProviderRequest.



500
501
502
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000- 0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


498
499
500
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 498

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



505
506
507
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 505

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
end