Class: Google::Apis::AgentidentityV1::ListAccessSummariesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentityV1::ListAccessSummariesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb
Overview
Message for response to listing AccessSummaries
Instance Attribute Summary collapse
-
#access_summaries ⇒ Array<Google::Apis::AgentidentityV1::AccessSummary>
The list of AccessSummary Corresponds to the JSON property
accessSummaries. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAccessSummariesResponse
constructor
A new instance of ListAccessSummariesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAccessSummariesResponse
Returns a new instance of ListAccessSummariesResponse.
636 637 638 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_summaries ⇒ Array<Google::Apis::AgentidentityV1::AccessSummary>
The list of AccessSummary
Corresponds to the JSON property accessSummaries
624 625 626 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 624 def access_summaries @access_summaries end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
629 630 631 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 629 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
634 635 636 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 634 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
641 642 643 644 645 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 641 def update!(**args) @access_summaries = args[:access_summaries] if args.key?(:access_summaries) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |