Class: Google::Apis::AgentidentityV1::ListAuthProvidersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentityV1::ListAuthProvidersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb
Overview
Message for response to listing AuthProviders
Instance Attribute Summary collapse
-
#auth_providers ⇒ Array<Google::Apis::AgentidentityV1::AuthProvider>
The list of AuthProvider Corresponds to the JSON property
authProviders. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAuthProvidersResponse
constructor
A new instance of ListAuthProvidersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAuthProvidersResponse
Returns a new instance of ListAuthProvidersResponse.
667 668 669 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_providers ⇒ Array<Google::Apis::AgentidentityV1::AuthProvider>
The list of AuthProvider
Corresponds to the JSON property authProviders
655 656 657 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 655 def auth_providers @auth_providers end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
660 661 662 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 660 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
665 666 667 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 665 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
672 673 674 675 676 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 672 def update!(**args) @auth_providers = args[:auth_providers] if args.key?(:auth_providers) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |