Class: Google::Apis::AgentidentityV1::QueryAuthProvidersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb

Overview

Response message for QueryAuthProviders.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryAuthProvidersResponse

Returns a new instance of QueryAuthProvidersResponse.



892
893
894
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_provider_namesArray<String>

The unique list of auth_provider resource names used by the workload. Corresponds to the JSON property authProviderNames

Returns:

  • (Array<String>)


884
885
886
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 884

def auth_provider_names
  @auth_provider_names
end

#next_page_tokenString

A token identifying a page of results the server should return. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 890

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



897
898
899
900
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 897

def update!(**args)
  @auth_provider_names = args[:auth_provider_names] if args.key?(:auth_provider_names)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end