Class: Google::Apis::AgentidentityV1::QueryWorkloadsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentityV1::QueryWorkloadsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb
Overview
Response message for QueryWorkloads.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#workload_ids ⇒ Array<String>
The unique list of workload identifiers (agents) that used the auth_provider.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryWorkloadsResponse
constructor
A new instance of QueryWorkloadsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryWorkloadsResponse
Returns a new instance of QueryWorkloadsResponse.
917 918 919 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
910 911 912 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 910 def next_page_token @next_page_token end |
#workload_ids ⇒ Array<String>
The unique list of workload identifiers (agents) that used the auth_provider.
Corresponds to the JSON property workloadIds
915 916 917 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 915 def workload_ids @workload_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
922 923 924 925 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 922 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @workload_ids = args[:workload_ids] if args.key?(:workload_ids) end |