Class: Google::Apis::AgentidentityV1::ThreeLeggedOAuth

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb

Overview

Message describing ThreeLeggedOAuth object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreeLeggedOAuth

Returns a new instance of ThreeLeggedOAuth.



1098
1099
1100
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorization_urlString

Optional. The authorization endpoint to send users to for consenting to delegate to the agent. eg. "https://auth.atlassian.com/authorize" Corresponds to the JSON property authorizationUrl

Returns:

  • (String)


1061
1062
1063
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1061

def authorization_url
  @authorization_url
end

#client_idString

Optional. The client ID of the OAuth client. Corresponds to the JSON property clientId

Returns:

  • (String)


1066
1067
1068
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1066

def client_id
  @client_id
end

#client_secretString

Optional. Input only. The client secret of the OAuth client. Corresponds to the JSON property clientSecret

Returns:

  • (String)


1071
1072
1073
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1071

def client_secret
  @client_secret
end

#default_continue_uriString

Optional. The default continue URI for 3LO flow and it will be used when no continue URI is provided in the RetrieveCredentials request. Corresponds to the JSON property defaultContinueUri

Returns:

  • (String)


1077
1078
1079
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1077

def default_continue_uri
  @default_continue_uri
end

#enable_pkceBoolean Also known as: enable_pkce?

Optional. Enables Proof Key for Code Exchange (PKCE) for the OAuth flow to prevent authorization code interception attacks. Corresponds to the JSON property enablePkce

Returns:

  • (Boolean)


1083
1084
1085
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1083

def enable_pkce
  @enable_pkce
end

#redirect_urlString

Output only. The redirect URL this auth_provider uses for the OAuth exchange. This is deterministic based on the name of the auth_provider. Corresponds to the JSON property redirectUrl

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1090

def redirect_url
  @redirect_url
end

#token_urlString

Optional. The token endpoint for requesting tokens on behalf of an end user. eg. "https://auth.atlassian.com/oauth/token" Corresponds to the JSON property tokenUrl

Returns:

  • (String)


1096
1097
1098
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1096

def token_url
  @token_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1103
1104
1105
1106
1107
1108
1109
1110
1111
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1103

def update!(**args)
  @authorization_url = args[:authorization_url] if args.key?(:authorization_url)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @default_continue_uri = args[:default_continue_uri] if args.key?(:default_continue_uri)
  @enable_pkce = args[:enable_pkce] if args.key?(:enable_pkce)
  @redirect_url = args[:redirect_url] if args.key?(:redirect_url)
  @token_url = args[:token_url] if args.key?(:token_url)
end