Class: Google::Apis::AgentidentityV1::AccessSummary
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentityV1::AccessSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb
Overview
Message describing AccessSummary object
Instance Attribute Summary collapse
-
#auth_provider ⇒ String
Output only.
-
#auth_provider_type ⇒ String
Output only.
-
#first_access_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#last_access_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#purge_time ⇒ String
Output only.
-
#scopes ⇒ Array<String>
Output only.
-
#token_url ⇒ String
Output only.
-
#user_id ⇒ String
Output only.
-
#workload_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AccessSummary
constructor
A new instance of AccessSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AccessSummary
Returns a new instance of AccessSummary.
90 91 92 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 90 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_provider ⇒ String
Output only. The auth_provider that this access summary is associated with.
Corresponds to the JSON property authProvider
32 33 34 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 32 def auth_provider @auth_provider end |
#auth_provider_type ⇒ String
Output only. The type of the connector that was used to create this access
summary.
Corresponds to the JSON property authProviderType
38 39 40 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 38 def auth_provider_type @auth_provider_type end |
#first_access_time ⇒ String
Output only. The first time this user has interacted with this workload.
Rounded to the previous hour.
Corresponds to the JSON property firstAccessTime
44 45 46 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 44 def first_access_time @first_access_time end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs
Corresponds to the JSON property labels
49 50 51 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 49 def labels @labels end |
#last_access_time ⇒ String
Output only. The most recent time this user has interacted with this workload.
Rounded to the previous hour.
Corresponds to the JSON property lastAccessTime
55 56 57 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 55 def last_access_time @last_access_time end |
#name ⇒ String
Output only. Identifier. Name of the AccessSummary
Corresponds to the JSON property name
60 61 62 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 60 def name @name end |
#purge_time ⇒ String
Output only. The time when this access summary is permanently deleted.
Corresponds to the JSON property purgeTime
65 66 67 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 65 def purge_time @purge_time end |
#scopes ⇒ Array<String>
Output only. All scopes that have been used by this user with this workload.
The number of scopes is limited to 200.
Corresponds to the JSON property scopes
71 72 73 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 71 def scopes @scopes end |
#token_url ⇒ String
Output only. The url of the authentication server that was accessed.
Corresponds to the JSON property tokenUrl
76 77 78 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 76 def token_url @token_url end |
#user_id ⇒ String
Output only. The user_id provided by the workload application for this user.
Not verified by Google.
Corresponds to the JSON property userId
82 83 84 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 82 def user_id @user_id end |
#workload_id ⇒ String
Output only. The identity bound to the workload that this user interacted with
to produce this AccessSummary. Will typically be an agentic spiffe id
Corresponds to the JSON property workloadId
88 89 90 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 88 def workload_id @workload_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 95 def update!(**args) @auth_provider = args[:auth_provider] if args.key?(:auth_provider) @auth_provider_type = args[:auth_provider_type] if args.key?(:auth_provider_type) @first_access_time = args[:first_access_time] if args.key?(:first_access_time) @labels = args[:labels] if args.key?(:labels) @last_access_time = args[:last_access_time] if args.key?(:last_access_time) @name = args[:name] if args.key?(:name) @purge_time = args[:purge_time] if args.key?(:purge_time) @scopes = args[:scopes] if args.key?(:scopes) @token_url = args[:token_url] if args.key?(:token_url) @user_id = args[:user_id] if args.key?(:user_id) @workload_id = args[:workload_id] if args.key?(:workload_id) end |