Class: Google::Apis::AgentidentityV1::AgentIdentityService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AgentidentityV1::AgentIdentityService
- Defined in:
- lib/google/apis/agentidentity_v1/service.rb
Overview
Agent Identity API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://agentidentity.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_auth_provider(parent, auth_provider_object = nil, auth_provider_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Creates a new AuthProvider in a given project and location.
-
#delete_project_location_auth_provider(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Empty
Deletes a single AuthProvider.
-
#delete_project_location_auth_provider_authorization(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Empty
Deletes a single Authorization.
-
#disable_auth_provider(name, disable_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Disables a single AuthProvider.
-
#enable_auth_provider(name, enable_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Enables a single AuthProvider.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Location
Gets information about a location.
-
#get_project_location_access_summary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AccessSummary
Gets details of a single AccessSummary.
-
#get_project_location_auth_provider(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Gets details of a single AuthProvider.
-
#get_project_location_auth_provider_authorization(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Authorization
Gets details of a single Authorization.
-
#get_project_location_auth_provider_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Policy
Gets the access control policy for a resource.
-
#initialize ⇒ AgentIdentityService
constructor
A new instance of AgentIdentityService.
-
#list_project_location_access_summaries(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListAccessSummariesResponse
Lists AccessSummaries in a given project and location.
-
#list_project_location_auth_provider_authorizations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListAuthorizationsResponse
Lists Authorizations in a given project and location.
-
#list_project_location_auth_providers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListAuthProvidersResponse
Lists AuthProviders in a given project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_auth_provider(name, auth_provider_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Updates the parameters of a single AuthProvider.
-
#query_project_location_auth_provider(parent, page_size: nil, page_token: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::QueryAuthProvidersResponse
Queries what all auth_providers are used by a given workload_id.
-
#query_project_location_auth_provider_workloads(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::QueryWorkloadsResponse
Queries what all workloads are using a given auth_provider.
-
#revoke_auth_provider_authorization(name, revoke_authorization_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::RevokeAuthorizationResponse
Revokes all authorizations for a specific user on an AuthProvider.
-
#set_auth_provider_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Policy
Sets the access control policy on the specified resource.
-
#test_auth_provider_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#undelete_auth_provider(name, undelete_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Undeletes a single AuthProvider.
Constructor Details
#initialize ⇒ AgentIdentityService
Returns a new instance of AgentIdentityService.
47 48 49 50 51 52 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-agentidentity_v1', client_version: Google::Apis::AgentidentityV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_project_location_auth_provider(parent, auth_provider_object = nil, auth_provider_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Creates a new AuthProvider in a given project and location.
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 259 def create_project_location_auth_provider(parent, auth_provider_object = nil, auth_provider_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/authProviders', ) command.request_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.request_object = auth_provider_object command.response_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.response_class = Google::Apis::AgentidentityV1::AuthProvider command.params['parent'] = parent unless parent.nil? command.query['authProviderId'] = auth_provider_id unless auth_provider_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_auth_provider(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Empty
Deletes a single AuthProvider.
304 305 306 307 308 309 310 311 312 313 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 304 def delete_project_location_auth_provider(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AgentidentityV1::Empty::Representation command.response_class = Google::Apis::AgentidentityV1::Empty command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_auth_provider_authorization(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Empty
Deletes a single Authorization.
828 829 830 831 832 833 834 835 836 837 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 828 def (name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AgentidentityV1::Empty::Representation command.response_class = Google::Apis::AgentidentityV1::Empty command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_auth_provider(name, disable_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Disables a single AuthProvider.
337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 337 def disable_auth_provider(name, disable_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:disable', ) command.request_representation = Google::Apis::AgentidentityV1::DisableAuthProviderRequest::Representation command.request_object = disable_auth_provider_request_object command.response_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.response_class = Google::Apis::AgentidentityV1::AuthProvider command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_auth_provider(name, enable_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Enables a single AuthProvider.
371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 371 def enable_auth_provider(name, enable_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enable', ) command.request_representation = Google::Apis::AgentidentityV1::EnableAuthProviderRequest::Representation command.request_object = enable_auth_provider_request_object command.response_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.response_class = Google::Apis::AgentidentityV1::AuthProvider command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AgentidentityV1::Location::Representation command.response_class = Google::Apis::AgentidentityV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_access_summary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AccessSummary
Gets details of a single AccessSummary.
160 161 162 163 164 165 166 167 168 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 160 def get_project_location_access_summary(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AgentidentityV1::AccessSummary::Representation command.response_class = Google::Apis::AgentidentityV1::AccessSummary command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_auth_provider(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Gets details of a single AuthProvider.
403 404 405 406 407 408 409 410 411 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 403 def get_project_location_auth_provider(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.response_class = Google::Apis::AgentidentityV1::AuthProvider command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_auth_provider_authorization(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Authorization
Gets details of a single Authorization.
859 860 861 862 863 864 865 866 867 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 859 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AgentidentityV1::Authorization::Representation command.response_class = Google::Apis::AgentidentityV1::Authorization command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_auth_provider_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
447 448 449 450 451 452 453 454 455 456 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 447 def get_project_location_auth_provider_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::AgentidentityV1::Policy::Representation command.response_class = Google::Apis::AgentidentityV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_access_summaries(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListAccessSummariesResponse
Lists AccessSummaries in a given project and location. Supported Filters: -
workload_id: Filter by the SPIFFE ID of the agent. Example: workload_id="
spiffe://example.com/ns/default/sa/my-agent"
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 206 def list_project_location_access_summaries(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/accessSummaries', ) command.response_representation = Google::Apis::AgentidentityV1::ListAccessSummariesResponse::Representation command.response_class = Google::Apis::AgentidentityV1::ListAccessSummariesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_auth_provider_authorizations(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListAuthorizationsResponse
Lists Authorizations in a given project and location.
904 905 906 907 908 909 910 911 912 913 914 915 916 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 904 def (parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/authorizations', ) command.response_representation = Google::Apis::AgentidentityV1::ListAuthorizationsResponse::Representation command.response_class = Google::Apis::AgentidentityV1::ListAuthorizationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_auth_providers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListAuthProvidersResponse
Lists AuthProviders in a given project and location.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 494 def list_project_location_auth_providers(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/authProviders', ) command.response_representation = Google::Apis::AgentidentityV1::ListAuthProvidersResponse::Representation command.response_class = Google::Apis::AgentidentityV1::ListAuthProvidersResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::AgentidentityV1::ListLocationsResponse::Representation command.response_class = Google::Apis::AgentidentityV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_auth_provider(name, auth_provider_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Updates the parameters of a single AuthProvider.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 548 def patch_project_location_auth_provider(name, auth_provider_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.request_object = auth_provider_object command.response_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.response_class = Google::Apis::AgentidentityV1::AuthProvider command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_project_location_auth_provider(parent, page_size: nil, page_token: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::QueryAuthProvidersResponse
Queries what all auth_providers are used by a given workload_id.
595 596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 595 def query_project_location_auth_provider(parent, page_size: nil, page_token: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/authProviders:query', ) command.response_representation = Google::Apis::AgentidentityV1::QueryAuthProvidersResponse::Representation command.response_class = Google::Apis::AgentidentityV1::QueryAuthProvidersResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['workloadId'] = workload_id unless workload_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_project_location_auth_provider_workloads(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::QueryWorkloadsResponse
Queries what all workloads are using a given auth_provider.
637 638 639 640 641 642 643 644 645 646 647 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 637 def query_project_location_auth_provider_workloads(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:queryWorkloads', ) command.response_representation = Google::Apis::AgentidentityV1::QueryWorkloadsResponse::Representation command.response_class = Google::Apis::AgentidentityV1::QueryWorkloadsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revoke_auth_provider_authorization(name, revoke_authorization_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::RevokeAuthorizationResponse
Revokes all authorizations for a specific user on an AuthProvider. This deletes all authorization records associated with the user and AuthProvider, effectively revoking access across all agents.
673 674 675 676 677 678 679 680 681 682 683 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 673 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:revokeAuthorization', ) command.request_representation = Google::Apis::AgentidentityV1::RevokeAuthorizationRequest::Representation command.request_object = command.response_representation = Google::Apis::AgentidentityV1::RevokeAuthorizationResponse::Representation command.response_class = Google::Apis::AgentidentityV1::RevokeAuthorizationResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_auth_provider_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
710 711 712 713 714 715 716 717 718 719 720 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 710 def set_auth_provider_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::AgentidentityV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::AgentidentityV1::Policy::Representation command.response_class = Google::Apis::AgentidentityV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_auth_provider_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
749 750 751 752 753 754 755 756 757 758 759 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 749 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AgentidentityV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AgentidentityV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AgentidentityV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#undelete_auth_provider(name, undelete_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AgentidentityV1::AuthProvider
Undeletes a single AuthProvider.
783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/google/apis/agentidentity_v1/service.rb', line 783 def undelete_auth_provider(name, undelete_auth_provider_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:undelete', ) command.request_representation = Google::Apis::AgentidentityV1::UndeleteAuthProviderRequest::Representation command.request_object = undelete_auth_provider_request_object command.response_representation = Google::Apis::AgentidentityV1::AuthProvider::Representation command.response_class = Google::Apis::AgentidentityV1::AuthProvider command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |