Class: Google::Apis::AgentidentityV1::EnableAuthProviderRequest
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentityV1::EnableAuthProviderRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb
Overview
Message for enabling an AuthProvider
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnableAuthProviderRequest
constructor
A new instance of EnableAuthProviderRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnableAuthProviderRequest
Returns a new instance of EnableAuthProviderRequest.
540 541 542 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. The request ID must be a
valid UUID with the exception that zero UUID is not supported (00000000-0000-
0000-0000-000000000000).
Corresponds to the JSON property requestId
538 539 540 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 538 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
545 546 547 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 545 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) end |