Class: Google::Apis::AgentidentityV1::UndeleteAuthProviderRequest
- Inherits:
-
Object
- Object
- Google::Apis::AgentidentityV1::UndeleteAuthProviderRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/agentidentity_v1/classes.rb,
lib/google/apis/agentidentity_v1/representations.rb,
lib/google/apis/agentidentity_v1/representations.rb
Overview
Message for undeleting a AuthProvider
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UndeleteAuthProviderRequest
constructor
A new instance of UndeleteAuthProviderRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UndeleteAuthProviderRequest
Returns a new instance of UndeleteAuthProviderRequest.
1159 1160 1161 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. The request ID must be a
valid UUID with the exception that zero UUID is not supported (00000000-0000-
0000-0000-000000000000).
Corresponds to the JSON property requestId
1157 1158 1159 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1157 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1164 1165 1166 |
# File 'lib/google/apis/agentidentity_v1/classes.rb', line 1164 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) end |